@@ -7,7 +7,7 @@ use poem::{
 use poem_openapi::{
     payload::{Json, PlainText},
     registry::{MetaHeader, MetaMediaType, MetaResponse, MetaResponses, MetaSchema, MetaSchemaRef},
-    Object, Response,
+    ApiResponse, Object,
 };
 use serde_json::Value;
 
@@ -17,7 +17,7 @@ struct BadRequestResult {
     message: String,
 }
 
-#[derive(Response)]
+#[derive(ApiResponse)]
 enum MyResponse {
     /// Ok
     #[oai(status = 200)]
@@ -28,7 +28,7 @@ enum MyResponse {
     /// C
     #[oai(status = 400)]
     BadRequest(Json<BadRequestResult>),
-    Default(StatusCode, PlainText),
+    Default(StatusCode, PlainText<String>),
 }
 
 #[test]
@@ -93,7 +93,7 @@ async fn into_response() {
 
 #[tokio::test]
 async fn headers() {
-    #[derive(Response)]
+    #[derive(ApiResponse)]
     enum MyResponse {
         #[oai(status = 200)]
         A,
@@ -110,7 +110,7 @@ async fn headers() {
         ),
         D(
             StatusCode,
-            PlainText,
+            PlainText<String>,
             #[oai(header = "MY-HEADER1")] i32,
             #[oai(header = "MY-HEADER2")] String,
         ),
